@@ -29,7 +29,6 @@
 #include <config.h>
 #include "nautilus-file-operations-progress.h"
 
-#include <eel/eel-ellipsizing-label.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
@@ -40,8 +39,8 @@
 #include <gtk/gtkstock.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtkvbox.h>
-#include <libgnome/gnome-i18n.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <glib/gi18n.h>
+#include <glib/gurifuncs.h>
 #include "nautilus-file-operations-progress-icons.h"
 
 /* The default width of the progress dialog. It will be wider
@@ -89,8 +88,8 @@ struct NautilusFileOperationsProgressDetails {
 	gulong files_total;
 	gulong file_index;
 	
-	GnomeVFSFileSize bytes_copied;
-	GnomeVFSFileSize bytes_total;
+	goffset bytes_copied;
+	goffset bytes_total;
 
 	/* system time (microseconds) when show timeout was started */
 	gint64 start_time;
@@ -151,9 +150,8 @@ nautilus_file_operations_progress_update (NautilusFileOperationsProgress *progre
 	char *remaining_time_string = NULL;
 
 	if (progress->details->bytes_total == 0) {
-		/* We haven't set up the file count yet, do not update
-		 * the progress bar until we do.
-		 */
+		/* We haven't set up the file count yet */
+		gtk_progress_bar_set_text (GTK_PROGRESS_BAR (progress->details->progress_bar), progress->details->progress_title);
 		return;
 	}
 
@@ -182,19 +180,19 @@ nautilus_file_operations_progress_update (NautilusFileOperationsProgress *progre
 }
 
 static void
-set_text_unescaped_trimmed (EelEllipsizingLabel *label, const char *text)
+set_text_unescaped_trimmed (GtkLabel *label, const char *text)
 {
 	char *unescaped_text;
 	char *unescaped_utf8;
 	
 	if (text == NULL || text[0] == '\0') {
-		eel_ellipsizing_label_set_text (label, "");
+		gtk_label_set_text (label, "");
 		return;
 	}
 	
-	unescaped_text = gnome_vfs_unescape_string_for_display (text);
+	unescaped_text = g_uri_unescape_string (text, G_URI_RESERVED_CHARS_ALLOWED_IN_PATH);
 	unescaped_utf8 = eel_make_valid_utf8 (unescaped_text);
-	eel_ellipsizing_label_set_text (label, unescaped_utf8);
+	gtk_label_set_text (label, unescaped_utf8);
 	g_free (unescaped_utf8);
 	g_free (unescaped_text);
 }
@@ -272,14 +270,15 @@ create_titled_label (GtkTable *table, int row, GtkWidget **title_widget, GtkWidg
 			  0, 0);
 	gtk_widget_show (*title_widget);
 
-	*label_text_widget = eel_ellipsizing_label_new ("");
+	*label_text_widget = gtk_label_new (NULL);
+        gtk_label_set_ellipsize (GTK_LABEL (*label_text_widget), PANGO_ELLIPSIZE_START);
+	gtk_misc_set_alignment (GTK_MISC (*label_text_widget), 0, 0);
 	gtk_table_attach (table, *label_text_widget,
 			  1, 2,
 			  row, row + 1,
 			  GTK_FILL | GTK_EXPAND, 0,
 			  0, 0);
 	gtk_widget_show (*label_text_widget);
-	gtk_misc_set_alignment (GTK_MISC (*label_text_widget), 0, 0);
 }
 
 static void
@@ -352,12 +351,12 @@ nautilus_file_operations_progress_init (NautilusFileOperationsProgress *progress
 	gtk_box_pack_start (GTK_BOX (progress_vbox), file_hbox, TRUE, TRUE, 2);
 
 	/* progress verb */
-	progress->details->operation_name_label = gtk_label_new ("");
+	progress->details->operation_name_label = gtk_label_new (NULL);
 	gtk_misc_set_alignment (GTK_MISC (progress->details->operation_name_label), 0.0, 0.0);
 	gtk_box_pack_start (GTK_BOX (file_hbox), progress->details->operation_name_label, FALSE, FALSE, 0);
 
 	/* file label */
-	progress->details->item_name = gtk_label_new ("");
+	progress->details->item_name = gtk_label_new (NULL);
 	gtk_misc_set_alignment (GTK_MISC (progress->details->item_name), 0.0, 0.0);
 	gtk_label_set_ellipsize (GTK_LABEL (progress->details->item_name), PANGO_ELLIPSIZE_END);
 	gtk_box_pack_start (GTK_BOX (file_hbox), progress->details->item_name, TRUE, TRUE, 0);
@@ -442,10 +441,10 @@ time_remaining_callback (gpointer callback_data)
 		/* This shouldn't be neccessary, but gnome-vfs seems to add the bytes processed during
 		 * the cleanup phase to bytes_copied. So we try avoid showing unrealistic ETAs here.
 		 */
-		str = g_strdup_printf ("%s", " ");
+		str = g_strdup (" ");
 	}
 	else if (time_remaining >= 3600) {
-		str = g_strdup_printf (_("(%d:%02d:%d Remaining)"), 
+		str = g_strdup_printf (_("(%d:%02d:%02d Remaining)"), 
 				       time_remaining / 3600, (time_remaining % 3600) / 60, (time_remaining % 3600) % 60);
 
 	}
@@ -487,7 +486,7 @@ nautilus_file_operations_progress_new (const char *title,
 				       const char *from_prefix,
 				       const char *to_prefix,
 				       gulong total_files,
-				       GnomeVFSFileSize total_bytes,
+				       goffset total_bytes,
 				       gboolean use_timeout)
 {
 	GtkWidget *widget;
@@ -502,10 +501,13 @@ nautilus_file_operations_progress_new (const char *title,
 
 	gtk_window_set_title (GTK_WINDOW (widget), title);
 	gtk_window_set_wmclass (GTK_WINDOW (widget), "file_progress", "Nautilus");
+	/* ensure that minimize button is shown and the window appears in the tasklist */
+	gtk_window_set_type_hint (GTK_WINDOW (widget), GDK_WINDOW_TYPE_HINT_NORMAL);
 
-	primary_text = g_strconcat ("<big><b>", title, "</b></big>", NULL);
+	primary_text = g_markup_printf_escaped ("<big><b>%s</b></big>", title);
 	gtk_label_set_markup(GTK_LABEL (progress->details->primary_text_label),
 			primary_text);
+	g_free (primary_text);
 
 	gtk_dialog_add_button (GTK_DIALOG (widget), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 
@@ -529,7 +531,7 @@ nautilus_file_operations_progress_new (const char *title,
 void
 nautilus_file_operations_progress_set_total (NautilusFileOperationsProgress *progress,
 					     gulong files_total,
-					     GnomeVFSFileSize bytes_total)
+					     goffset bytes_total)
 {
 	g_return_if_fail (NAUTILUS_IS_FILE_OPERATIONS_PROGRESS (progress));
 
@@ -547,6 +549,8 @@ nautilus_file_operations_progress_set_operation_string (NautilusFileOperationsPr
 
 	g_free (progress->details->progress_title);
 	progress->details->progress_title = g_strdup (operation_string);
+
+	nautilus_file_operations_progress_update (progress);
 }
 
 void
@@ -558,7 +562,7 @@ nautilus_file_operations_progress_new_file (NautilusFileOperationsProgress *prog
 					    const char *from_prefix,
 					    const char *to_prefix,
 					    gulong file_index,
-					    GnomeVFSFileSize size)
+					    goffset size)
 {
 	char *operation_markup;
 	char *item_markup;
@@ -572,24 +576,25 @@ nautilus_file_operations_progress_new_file (NautilusFileOperationsProgress *prog
 		/* we haven't set up the file count yet, do not update the progress
 		 * count until we do
 		 */
-		operation_markup = g_strconcat ("<i>", progress_verb, "</i>", NULL);
+		operation_markup = g_markup_printf_escaped ("<i>%s</i>", progress_verb);
 		gtk_label_set_markup (GTK_LABEL (progress->details->operation_name_label),
 				    operation_markup);
+		g_free (operation_markup);
 
-		item_markup = g_strconcat ("<i>\"", item_name, "\"</i>", NULL);
-
+		item_markup = g_markup_printf_escaped ("<i>%s</i>", item_name);
 		gtk_label_set_markup (GTK_LABEL (progress->details->item_name), item_markup);
+		g_free (item_markup);
 
 		progress->details->file_index = file_index;
 
 		gtk_label_set_text (GTK_LABEL (progress->details->from_label), from_prefix);
 		set_text_unescaped_trimmed 
-			(EEL_ELLIPSIZING_LABEL (progress->details->from_path_label), from_path);
+			(GTK_LABEL (progress->details->from_path_label), from_path);
 	
 		if (progress->details->to_prefix != NULL && progress->details->to_path_label != NULL) {
 			gtk_label_set_text (GTK_LABEL (progress->details->to_label), to_prefix);
 			set_text_unescaped_trimmed 
-				(EEL_ELLIPSIZING_LABEL (progress->details->to_path_label), to_path);
+				(GTK_LABEL (progress->details->to_path_label), to_path);
 		}
 
 		if (progress->details->first_transfer_time == 0) {
@@ -616,8 +621,8 @@ nautilus_file_operations_progress_clear (NautilusFileOperationsProgress *progres
 
 void
 nautilus_file_operations_progress_update_sizes (NautilusFileOperationsProgress *progress,
-						GnomeVFSFileSize bytes_done_in_file,
-						GnomeVFSFileSize bytes_done)
+						goffset bytes_done_in_file,
+						goffset bytes_done)
 {
 	g_return_if_fail (NAUTILUS_IS_FILE_OPERATIONS_PROGRESS (progress));
 
