@@ -171,6 +171,7 @@ gboolean                nautilus_file_is_mime_type                      (Nautilu
 gboolean                nautilus_file_is_launchable                     (NautilusFile                   *file);
 gboolean                nautilus_file_is_symbolic_link                  (NautilusFile                   *file);
 gboolean                nautilus_file_is_mountpoint                     (NautilusFile                   *file);
+GMount *                nautilus_file_get_mount                         (NautilusFile                   *file);
 char *                  nautilus_file_get_volume_free_space             (NautilusFile                   *file);
 char *                  nautilus_file_get_volume_name                   (NautilusFile                   *file);
 char *                  nautilus_file_get_symbolic_link_target_path     (NautilusFile                   *file);
@@ -251,12 +252,8 @@ void                    nautilus_file_mount                             (Nautilu
 									 GCancellable                   *cancellable,
 									 NautilusFileOperationCallback   callback,
 									 gpointer                        callback_data);
-void                    nautilus_file_unmount                           (NautilusFile                   *file,
-									 NautilusFileOperationCallback   callback,
-									 gpointer                        callback_data);
-void                    nautilus_file_eject                             (NautilusFile                   *file,
-									 NautilusFileOperationCallback   callback,
-									 gpointer                        callback_data);
+void                    nautilus_file_unmount                           (NautilusFile                   *file);
+void                    nautilus_file_eject                             (NautilusFile                   *file);
 
 /* Basic operations for file objects. */
 void                    nautilus_file_set_owner                         (NautilusFile                   *file,
@@ -327,8 +324,12 @@ void                    nautilus_file_set_integer_metadata              (Nautilu
 /* Attributes for file objects as user-displayable strings. */
 char *                  nautilus_file_get_string_attribute              (NautilusFile                   *file,
 									 const char                     *attribute_name);
+char *                  nautilus_file_get_string_attribute_q            (NautilusFile                   *file,
+									 GQuark                          attribute_q);
 char *                  nautilus_file_get_string_attribute_with_default (NautilusFile                   *file,
 									 const char                     *attribute_name);
+char *                  nautilus_file_get_string_attribute_with_default_q (NautilusFile                  *file,
+									 GQuark                          attribute_q);
 char *			nautilus_file_fit_modified_date_as_string	(NautilusFile 			*file,
 									 int				 width,
 									 NautilusWidthMeasureCallback    measure_callback,
@@ -353,6 +354,11 @@ int                     nautilus_file_compare_for_sort_by_attribute     (Nautilu
 									 const char                     *attribute,
 									 gboolean                        directories_first,
 									 gboolean                        reversed);
+int                     nautilus_file_compare_for_sort_by_attribute_q   (NautilusFile                   *file_1,
+									 NautilusFile                   *file_2,
+									 GQuark                          attribute,
+									 gboolean                        directories_first,
+									 gboolean                        reversed);
 int                     nautilus_file_compare_display_name              (NautilusFile                   *file_1,
 									 const char                     *pattern);
 
@@ -370,7 +376,9 @@ GList                  *nautilus_file_list_filter_hidden_and_backup     (GList
 /* Get the URI that's used when activating the file.
  * Getting this can require reading the contents of the file.
  */
+gboolean                nautilus_file_has_activation_uri                (NautilusFile                   *file);
 char *                  nautilus_file_get_activation_uri                (NautilusFile                   *file);
+GFile *                 nautilus_file_get_activation_location           (NautilusFile                   *file);
 
 char *                  nautilus_file_get_drop_target_uri               (NautilusFile                   *file);
 
@@ -478,12 +486,8 @@ typedef struct {
 							  GCancellable                   *cancellable,
 							  NautilusFileOperationCallback   callback,
 							  gpointer                        callback_data);
-	void                 (* unmount)                 (NautilusFile                   *file,
-							  NautilusFileOperationCallback   callback,
-							  gpointer                        callback_data);
-	void                 (* eject)                   (NautilusFile                   *file,
-							  NautilusFileOperationCallback   callback,
-							  gpointer                        callback_data);
+	void                 (* unmount)                 (NautilusFile *file);
+	void                 (* eject)                   (NautilusFile *file);
 } NautilusFileClass;
 
 #endif /* NAUTILUS_FILE_H */
