@@ -3,7 +3,7 @@
 #include <eel/eel-wrap-table.h>
 #include <eel/eel-labeled-image.h>
 #include <libnautilus-private/nautilus-customization-data.h>
-#include <libnautilus-private/nautilus-icon-factory.h>
+#include <libnautilus-private/nautilus-icon-info.h>
 
 int 
 main (int argc, char* argv[])
